#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-core
version:              2.11.7
visibility:           public
id:                   hspec-core-2.11.7-HotbjCCfIW874glOl9sFNp
key:                  hspec-core-2.11.7-HotbjCCfIW874glOl9sFNp
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  07f81893784197376d966753434d2e54
exposed:              True
exposed-modules:
    Test.Hspec.Core.Format Test.Hspec.Core.Formatters
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.Runner Test.Hspec.Core.Spec Test.Hspec.Core.Util

hidden-modules:
    GetOpt.Declarative GetOpt.Declarative.Environment
    GetOpt.Declarative.Interpret GetOpt.Declarative.Types
    GetOpt.Declarative.Util NonEmpty Test.Hspec.Core.Clock
    Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Definition Test.Hspec.Core.Config.Options
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Pretty
    Test.Hspec.Core.Formatters.Pretty.Parser
    Test.Hspec.Core.Formatters.Pretty.Parser.Parser
    Test.Hspec.Core.Formatters.Pretty.Unicode
    Test.Hspec.Core.Formatters.V1.Free
    Test.Hspec.Core.Formatters.V1.Internal
    Test.Hspec.Core.Formatters.V1.Monad Test.Hspec.Core.QuickCheckUtil
    Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Runner.JobQueue
    Test.Hspec.Core.Runner.PrintSlowSpecItems
    Test.Hspec.Core.Runner.Result Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
    Test.Hspec.Core.Tree Control.Concurrent.Async Data.Algorithm.Diff
    Paths_hspec_core

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-core-2.11.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-core-2.11.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-core-2.11.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-core
hs-libraries:         HShspec-core-2.11.7-HotbjCCfIW874glOl9sFNp
depends:
    HUnit-1.6.2.0-L1r9G4r6Tqe7YoPeBDc5p3
    QuickCheck-2.15.0.1-HW6HIMYjXnYB7OQUyImYOa
    ansi-terminal-1.1-FMAjddYCnoo35p0Ajg6Jk8 array-0.5.6.0
    base-4.18.2.1 call-stack-0.4.0-2YwW5DB9oZp9WckTZ0XzI6
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.300.1
    haskell-lexer-1.2-1vamZPabniXHcMPDyEaor0
    hspec-expectations-0.8.4-KDdqNp0px8sIhjWBtMxbQb process-1.6.19.0
    quickcheck-io-0.2.0-J9FZCUjUR4CBeGu7uTMUSr
    random-1.2.1.3-FxwYxgjgoojJKMc450MWAC stm-2.5.1.0
    tf-random-0.5-Beg8trNQX3GZEp2sLyOT6 time-1.12.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html:         /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

